/**
 *	Copyright (c) 2008,  Eckhart Arnold
 *
 * Dieses Programm ist freie Software. Sie können es unter den
 * Bedingungen der GNU General Public License, wie von der Free
 * Software Foundation veröffentlicht, weitergeben und/oder
 * modifizieren, entweder gemäß Version 3 der Lizenz oder (nach
 * Ihrer Option) jeder späteren Version.
 *
 * Die Veröffentlichung dieses Programms erfolgt in der Hoffnung,
 * daß es Ihnen von Nutzen sein wird, aber OHNE IRGENDEINE
 * GARANTIE, sogar ohne die implizite Garantie der MARKTREIFE oder
 * der VERWENDBARKEIT FÜR EINEN BESTIMMTEN ZWECK. Details finden
 * Sie in der GNU General Public License.
 *
 * Sie sollten ein Exemplar der GNU General Public License zusammen
 * mit diesem Programm erhalten haben. Falls nicht, siehe
 * <http://www.gnu.org/licenses/>.
 */

package evolution.examples;

import org.eclipse.swt.graphics.GC;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.graphics.Rectangle;

public class SimpleTest implements ISimulation {
	private StringBuffer log = new StringBuffer();
	private int startC, stopC, counter;

	public SimpleTest(int startCounter, int stopCounter) {
		startC = startCounter;
		stopC = stopCounter;
		counter = startC;
	}

	public String getDescription() {
		return "Just a simple test of the framework: "+
        "The test simulation slowly counts " +
        "from " + startC + " to " + stopC + " .";
	}

	public void reset() {
		counter = startC;
		int l = log.length();
		if (l > 0) log.delete(0, l-1);
	}

	public void step() {
		assert counter < stopC;
		counter++;
		try {
			Thread.sleep(200);
		} catch (InterruptedException e) {
			log.append("\nInterruptedExcpetion caught!\n");
		}
		log.append(counter+" ");
	}

	public boolean finished() {
		return counter >= stopC;
	}
	
	public void terminate() { /* no cleanup necessary */ }

	public void drawState(GC gc) {
		String output = "Counter: " + counter;
		Point e = gc.stringExtent(output);
		Rectangle r = gc.getClipping();
		gc.fillRectangle(r);
		gc.drawString(output, r.x+(r.width-e.x)/2, r.y+(r.height-e.y)/2);
	}

	public StringBuffer accessLog() {
		return log;
	}
	
	public String[] queryMonitors() {
		String[] monitors = { "monitor" };
		return monitors;
	}
	
	public double readMonitor(String monitor) {
		assert monitor == "monitor";
		return (double) counter;
	}
}
